low-disc.core


haltonclj

(halton ps bs)
(halton ps bs l)

Returns the Halton sequence for bases bs scrambled with permutations ps.

Returns the Halton sequence for bases bs scrambled with permutations ps.
sourceraw docstring

halton-10dclj

source

halton-11dclj

source

halton-12dclj

source

halton-13dclj

source

halton-14dclj

source

halton-15dclj

source

halton-16dclj

source

halton-1dclj

source

halton-2dclj

source

halton-3dclj

source

halton-4dclj

source

halton-5dclj

source

halton-6dclj

source

halton-7dclj

source

halton-8dclj

source

halton-9dclj

source

halton-ndclj

(halton-nd n)
(halton-nd n l)

Returns an n-dimensional scrambled Halton sequence.

Without an explicitly given length l, an infinite sequence is created

The first n prime numbers act as bases.

Scrambling is performed using the permutations found using Braaten and Weller's algorithm by Vandewoestyne and Cools (https://doi.org/10.1016/j.cam.2005.05.022).

Returns an n-dimensional scrambled Halton sequence.

Without an explicitly given length l, an infinite sequence is created

The first n prime numbers act as bases.

Scrambling is performed using the permutations found using Braaten and Weller's algorithm by
Vandewoestyne and Cools (https://doi.org/10.1016/j.cam.2005.05.022).
sourceraw docstring

halton-unscrclj

(halton-unscr bs)
(halton-unscr bs l)

Returns the unscrambled Halton sequence for bases bs.

Without an explicitly given length l, an infinite sequence is created.

Returns the unscrambled Halton sequence for bases bs.

Without an explicitly given length l, an infinite sequence is created.
sourceraw docstring

halton-unscr-10dclj

source

halton-unscr-11dclj

source

halton-unscr-12dclj

source

halton-unscr-13dclj

source

halton-unscr-14dclj

source

halton-unscr-15dclj

source

halton-unscr-16dclj

source

halton-unscr-1dclj

source

halton-unscr-2dclj

source

halton-unscr-3dclj

source

halton-unscr-4dclj

source

halton-unscr-5dclj

source

halton-unscr-6dclj

source

halton-unscr-7dclj

source

halton-unscr-8dclj

source

halton-unscr-9dclj

source

halton-unscr-ndclj

(halton-unscr-nd n)
(halton-unscr-nd n l)

Returns an n-dimensional unscrambled Halton sequence.

Without an explicitly given length l, an infinite sequence is created

The first n prime numbers act as bases.

Returns an n-dimensional unscrambled Halton sequence.

Without an explicitly given length l, an infinite sequence is created

The first n prime numbers act as bases.
sourceraw docstring

hammersley-10dclj

source

hammersley-11dclj

source

hammersley-12dclj

source

hammersley-13dclj

source

hammersley-14dclj

source

hammersley-15dclj

source

hammersley-16dclj

source

hammersley-1dclj

source

hammersley-2dclj

source

hammersley-3dclj

source

hammersley-4dclj

source

hammersley-5dclj

source

hammersley-6dclj

source

hammersley-7dclj

source

hammersley-8dclj

source

hammersley-9dclj

source

hammersley-ndclj

(hammersley-nd n l)
source

hammersley-unscr-10dclj

source

hammersley-unscr-11dclj

source

hammersley-unscr-12dclj

source

hammersley-unscr-13dclj

source

hammersley-unscr-14dclj

source

hammersley-unscr-15dclj

source

hammersley-unscr-16dclj

source

hammersley-unscr-1dclj

source

hammersley-unscr-2dclj

source

hammersley-unscr-3dclj

source

hammersley-unscr-4dclj

source

hammersley-unscr-5dclj

source

hammersley-unscr-6dclj

source

hammersley-unscr-7dclj

source

hammersley-unscr-8dclj

source

hammersley-unscr-9dclj

source

hammersley-unscr-ndclj

(hammersley-unscr-nd n l)
source

uniform-10dclj

source

uniform-11dclj

source

uniform-12dclj

source

uniform-13dclj

source

uniform-14dclj

source

uniform-15dclj

source

uniform-16dclj

source

uniform-1dclj

source

uniform-2dclj

source

uniform-3dclj

source

uniform-4dclj

source

uniform-5dclj

source

uniform-6dclj

source

uniform-7dclj

source

uniform-8dclj

source

uniform-9dclj

source

uniform-ndclj

(uniform-nd n)
(uniform-nd n l)

Return a lazy sequence of n-dimensional points chosen independently and uniformly at random.

Without an explicitly given length l, an infinite sequence is created.

Return a lazy sequence of n-dimensional points chosen independently and uniformly at random.

Without an explicitly given length l, an infinite sequence is created.
sourceraw docstring

uniform-nd-pointclj

(uniform-nd-point n)
source

vdcclj

(vdc p b)
(vdc p b l)

Returns the base b van der Corput sequence scrambled with permutation p.

Without an explicitly given length l, an infinite sequence is created.

Returns the base b van der Corput sequence scrambled with permutation p.

Without an explicitly given length l, an infinite sequence is created.
sourceraw docstring

vdc-elclj

(vdc-el p b n)
source

vdc-unscrclj

(vdc-unscr b)
(vdc-unscr b l)

Returns the unscrambled base b van der Corput sequence.

Without an explicitly given length l, an infinite sequence is created.

Returns the unscrambled base b van der Corput sequence.

Without an explicitly given length l, an infinite sequence is created.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries