(halton ps bs)(halton ps bs l)Returns the Halton sequence for bases bs scrambled with permutations ps.
Returns the Halton sequence for bases bs scrambled with permutations ps.
(halton-nd n)(halton-nd n l)Returns an n-dimensional scrambled Halton sequence.
Without an explicitly given length l, an infinite sequence is created
The first n prime numbers act as bases.
Scrambling is performed using the permutations found using Braaten and Weller's algorithm by Vandewoestyne and Cools (https://doi.org/10.1016/j.cam.2005.05.022).
Returns an n-dimensional scrambled Halton sequence. Without an explicitly given length l, an infinite sequence is created The first n prime numbers act as bases. Scrambling is performed using the permutations found using Braaten and Weller's algorithm by Vandewoestyne and Cools (https://doi.org/10.1016/j.cam.2005.05.022).
(halton-unscr bs)(halton-unscr bs l)Returns the unscrambled Halton sequence for bases bs.
Without an explicitly given length l, an infinite sequence is created.
Returns the unscrambled Halton sequence for bases bs. Without an explicitly given length l, an infinite sequence is created.
(halton-unscr-nd n)(halton-unscr-nd n l)Returns an n-dimensional unscrambled Halton sequence.
Without an explicitly given length l, an infinite sequence is created
The first n prime numbers act as bases.
Returns an n-dimensional unscrambled Halton sequence. Without an explicitly given length l, an infinite sequence is created The first n prime numbers act as bases.
(uniform-nd n)(uniform-nd n l)Return a lazy sequence of n-dimensional points chosen independently and uniformly at random.
Without an explicitly given length l, an infinite sequence is created.
Return a lazy sequence of n-dimensional points chosen independently and uniformly at random. Without an explicitly given length l, an infinite sequence is created.
(vdc p b)(vdc p b l)Returns the base b van der Corput sequence scrambled with permutation p.
Without an explicitly given length l, an infinite sequence is created.
Returns the base b van der Corput sequence scrambled with permutation p. Without an explicitly given length l, an infinite sequence is created.
(vdc-unscr b)(vdc-unscr b l)Returns the unscrambled base b van der Corput sequence.
Without an explicitly given length l, an infinite sequence is created.
Returns the unscrambled base b van der Corput sequence. Without an explicitly given length l, an infinite sequence is created.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |